==> vtigercrm-5.2.1.tgz: modules/ServiceContracts/language/es_es.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/

$mod_strings = Array (
'Service Contracts' => 'Contratos de Servicio',
'ServiceContracts' => 'Contratos de Servicio',
'SINGLE_ServiceContracts' => 'Contrato de Servicio',
'LBL_SERVICE_CONTRACT_INFORMATION' => 'Información Contrato de Servicio',
'LBL_CUSTOM_INFORMATION' => 'Información Personalizada',
'Contract No' => 'Número Contrato',
'Due date' => 'Fecha vencimiento',
'Assigned To' => 'Asignado a',
'Created Time' => 'Fecha creación',
'Modified Time' => 'Fecha modificación',
'Start Date' => 'Fecha inicio',
'End Date' => 'Fecha fin',
'Related to' => 'Relacionado con',
'Tracking Unit' => 'Unidad de seguimiento',
'Total Units' => 'Total Unidades',
'Used Units' => 'Unidades consumidas',
'Subject' => 'Referencia',
'Progress'=> 'Progreso (en %)',

'Type' => 'Tipo',
'Planned Duration'=>'Duración estimada (días)',
'Actual Duration'=>'Duración real (días)',
'Status' => 'Estado',
'Priority' => 'Prioridad',

'Undefined' => 'Indefinido',
'In Planning' => 'Planificado',
'In Progress' => 'En progreso',
'On Hold' => 'En espera',
'Complete' => 'Completado',
'Archived' => 'Archivado',

'Support' => 'Soporte',
'Services' => 'Servicios',
'Administrative' => 'Administrativo',

'Low'=>'Baja',
'Normal'=>'Normal',
'High'=>'Alta',

'None'=>'Ninguno',
'Hours'=>'Horas',
'Days'=>'Días',
'Incidents'=>'Incidentes',
'Service Requests'=>'Peticiones de Servicio',

/*
 * 5.2.0 changes 
 */
'LBL_MODULE_NAME'=>'Contratos de Servicio',

);

?>

==> vtigercrm-5.4.0.tgz: modules/ServiceContracts/language/es_es.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 * 
 *  ********************************************************************************
 *  Module       : ServiceContracts
 *  Language     : Español
 *  Version      : 5.4.0 
 *  Last change  : 2012-02-27
 *  Author       : Joe Bordes JPL TSolucio, S.L.
 ************************************************************************************/

$mod_strings = Array (
'Service Contracts' => 'Contratos de Servicio',
'ServiceContracts' => 'Contratos de Servicio',
'SINGLE_ServiceContracts' => 'Contrato de Servicio',
'LBL_SERVICE_CONTRACT_INFORMATION' => 'Información Contrato de Servicio',
'LBL_CUSTOM_INFORMATION' => 'Información Personalizada',
'Contract No' => 'Número Contrato',
'Due date' => 'Fecha vencimiento',
'Assigned To' => 'Asignado a',
'Created Time' => 'Fecha creación',
'Modified Time' => 'Fecha modificación',
'Start Date' => 'Fecha inicio',
'End Date' => 'Fecha fin',
'Related to' => 'Relacionado con',
'Tracking Unit' => 'Unidad de seguimiento',
'Total Units' => 'Total Unidades',
'Used Units' => 'Unidades consumidas',
'Subject' => 'Referencia',
'Progress'=> 'Progreso',

'Type' => 'Tipo',
'Planned Duration'=>'Duración estimada (días)',
'Actual Duration'=>'Duración real (días)',
'Status' => 'Estado',
'Priority' => 'Prioridad',

'Undefined' => 'Indefinido',
'In Planning' => 'Planificado',
'In Progress' => 'En progreso',
'On Hold' => 'En espera',
'Complete' => 'Completado',
'Archived' => 'Archivado',

'Support' => 'Soporte',
'Services' => 'Servicios',
'Administrative' => 'Administrativo',

'Low'=>'Baja',
'Normal'=>'Normal',
'High'=>'Alta',

'None'=>'Ninguno',
'Hours'=>'Horas',
'Days'=>'Días',
'Incidents'=>'Incidentes',
'Service Requests'=>'Peticiones de Servicio',

/*
 * 5.2.0 changes 
 */
'LBL_MODULE_NAME'=>'Contratos de Servicio',

'ServiceContracts ID'=>'Id Contrato Servicio',
);

?>
